==> gnuradio_3.6.5.1.orig.tar.gz: gnuradio-3.6.5.1/gr-blocks/lib/burst_tagger_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2010,2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_GR_BURST_TAGGER_IMPL_H
#define INCLUDED_GR_BURST_TAGGER_IMPL_H

#include <blocks/burst_tagger.h>

namespace gr {
  namespace blocks {

    class burst_tagger_impl : public burst_tagger
    {
    private:
      size_t     d_itemsize;
      bool       d_state;
      pmt::pmt_t d_true_key;
      pmt::pmt_t d_true_value;

      pmt::pmt_t d_false_key;
      pmt::pmt_t d_false_value;

      pmt::pmt_t d_id;

    public:
      burst_tagger_impl(size_t itemsize);
      ~burst_tagger_impl();

      void set_true_tag(const std::string &key, bool value);
      void set_false_tag(const std::string &key, bool value);

      int work(int noutput_items,
               gr_vector_const_void_star &input_items,
               gr_vector_void_star &output_items);
    };

  } /* namespace blocks */
} /* namespace gr */

#endif /* INCLUDED_GR_BURST_TAGGER_IMPL_H */

==> gnuradio_3.7.2.1.orig.tar.gz: gnuradio-3.7.2.1/gr-blocks/lib/burst_tagger_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2010,2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_GR_BURST_TAGGER_IMPL_H
#define INCLUDED_GR_BURST_TAGGER_IMPL_H

#include <gnuradio/blocks/burst_tagger.h>

namespace gr {
  namespace blocks {

    class burst_tagger_impl : public burst_tagger
    {
    private:
      size_t     d_itemsize;
      bool       d_state;
      pmt::pmt_t d_true_key;
      pmt::pmt_t d_true_value;

      pmt::pmt_t d_false_key;
      pmt::pmt_t d_false_value;

      pmt::pmt_t d_id;

    public:
      burst_tagger_impl(size_t itemsize);
      ~burst_tagger_impl();

      void set_true_tag(const std::string &key, bool value);
      void set_false_tag(const std::string &key, bool value);

      int work(int noutput_items,
               gr_vector_const_void_star &input_items,
               gr_vector_void_star &output_items);
    };

  } /* namespace blocks */
} /* namespace gr */

#endif /* INCLUDED_GR_BURST_TAGGER_IMPL_H */
